@@ -21,8 +21,11 @@
 
 
 import django_tables2 as tables
+
 from django.contrib.contenttypes.models import ContentType
 from django.utils.safestring import mark_safe
+from django.utils.html import escape
+
 from lava.utils.lavatable import LavaTable
 from lava_scheduler_app.tables import RestrictedIDLinkColumn
 from lava_results_app.models import (
@@ -30,7 +33,6 @@ from lava_results_app.models import (
     BugLink,
     TestSuite
 )
-from markupsafe import escape
 
 
 def results_pklink(record):
