@@ -769,7 +769,7 @@ class SchedulerAPI(ExposedAPI):
         The elements available in XML-RPC structure include:
         _results_link, _state, submitter_id, submit_token_id, is_pipeline,
         id, failure_comment, multinode_definition, user_id,
-        priority, _actual_device_cache, vm_group, original_definition,
+        priority, _actual_device_cache, original_definition,
         status, health_check, description, admin_notifications, start_time,
         target_group, visibility, requested_device_id, pipeline_compatibility,
         submit_time, is_public, _old_status, actual_device_id, definition,
