@@ -146,7 +146,7 @@ BRANDING_ICON = 'lava-server/images/logo.png'
 BRANDING_URL = 'http://www.linaro.org'
 BRANDING_HEIGHT = "BRANDING_HEIGHT", 22
 BRANDING_WIDTH = "BRANDING_WIDTH", 22
-BRANDING_BUG_URL = "https://bugs.linaro.org/enter_bug.cgi?product=LAVA%20Framework"
+BRANDING_BUG_URL = "https://lists.linaro.org/mailman/listinfo/lava-users"
 BRANDING_SOURCE_URL = "https://git.linaro.org/lava"
 BRANDING_MESSAGE = ''
 
