@@ -21,3 +21,10 @@ from lava_server.settings.common import *
 
 DEBUG = False
 TEMPLATE_DEBUG = DEBUG
+
+# Add a memory based cache
+CACHES = {
+    'default': {
+        'BACKEND': 'django.core.cache.backends.locmem.LocMemCache',
+    }
+}
